#include <Wire.h>
#include <MPU6050.h>
#include <BleMouse.h>

MPU6050 mpu;
BleMouse bleMouse;

const int leftButtonPin = 12;
const int rightButtonPin = 14;

int16_t ax, ay, az;
int16_t gx, gy, gz;

float sensitivity = 0.2;  // Adjust this value to change mouse sensitivity

void setup() {
  Serial.begin(9600);
  Wire.begin();
  
  mpu.initialize();
  
  pinMode(leftButtonPin, INPUT);
  pinMode(rightButtonPin, INPUT);
  
  bleMouse.begin();
  Serial.println("Bluetooth Mouse started");
}

void loop() {
  if(bleMouse.isConnected()) {
    // Read accelerometer and gyroscope values
    mpu.getMotion6(&ax, &ay, &az, &gx, &gy, &gz);
    
    // Calculate mouse movement based on gyroscope data
    int mouseX = -gy / 200 * sensitivity;
    int mouseY = gx / 200 * sensitivity;
    
    // Move the mouse if there's significant movement
    if(abs(mouseX) > 0 || abs(mouseY) > 0) {
      bleMouse.move(mouseX, mouseY);
    }
    
    // Check button states and perform clicks
    if(digitalRead(leftButtonPin) == HIGH) {
      bleMouse.click(MOUSE_LEFT);
      Serial.println("Left Button Clicked");
      delay(1000);  // Debounce delay
    }
    
    if(digitalRead(rightButtonPin) == HIGH) {
      bleMouse.click(MOUSE_RIGHT);
      Serial.println("Right Button Clicked");
      delay(1000);  // Debounce delay
    }
  }
  
  delay(10);  // Small delay to prevent overwhelming the BLE stack
}
